==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/components/home/app_bar_profile.dart <==
part of tecfy_corev2_client_package;

class AppBarProfile extends StatelessWidget {
  /// title string
  final String title;

  /// bottom bar widget
  final Widget? bottomBar;

  /// action list
  final List<Widget>? actions;

  /// photo URL
  final String? photoUrl;

  /// on press function
  final void Function()? onPress;
  AppBarProfile(this.title,
      {this.bottomBar, this.actions, this.photoUrl, this.onPress});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(top: 30.0),
      color: Colors.white,
      height: bottomBar == null ? 110.0 : 160.0,
      child: bottomBar == null
          ? _titleBar(context)
          : Column(
              children: <Widget>[
                Container(height: 80.0, child: _titleBar(context)),
                bottomBar ?? Container()
              ],
            ),
    );
  }

  _titleBar(context) {
    return Row(children: <Widget>[
      GestureDetector(
          onTap: onPress ??
              // () => AppNavigator.navigateToNamed(context, '/setting'),
              () => AppNavigator.showAppDialogEx(
                  context, () => SettingPage(true),
                  size: DialogBoxSizes.large,
                  barrierDismissible: true,
                  title: AppLocale.translate('Settings')),
          child: Container(
              width: 70.0,
              height: 100.0,
              child: Stack(
                children: <Widget>[
                  Image.asset(
                    'assets/images/profile back.png',
                    fit: BoxFit.fill,
                    width: 70.0,
                    height: 100.0,
                  ),
                  Padding(
                      padding: EdgeInsets.only(top: 15.5, left: 17),
                      child: CircleAvatar(
                        minRadius: 24.5,
                        maxRadius: 24.5,
                        backgroundColor: Colors.white,
                        backgroundImage: NetworkImage(
                            photoUrl ?? // ConfigService.user?.url ??
                                'https://upload.wikimedia.org/wikipedia/commons/7/7c/Profile_avatar_placeholder_large.png'),
                      ))
                ],
              ))),

      //SizedBox(width: 70.0),
      Expanded(
          child: TecfyText(title,
              textAlign: TextAlign.center,
              style: TextStyle(
                  color: ThemeService.mainColor,
                  fontSize: 20.0,
                  fontWeight: FontWeight.w600))),
      // IconButton(
      //     onPressed: () {},
      //     icon: Icon(Icons.search,
      //         size: 35.0, color: ThemeService.mainColor)),
      actions != null && actions!.length > 0
          ? actions!.first
          : SizedBox(width: 70.0),
      actions != null && actions!.length > 1 ? actions!.last : Container(),
      SizedBox(width: 20.0)
    ]);
  }
}

==> tecfy_corev2_package-1.1.117.tar.gz: lib/views/components/home/app_bar_profile.dart <==
part of tecfy_corev2_client_package;

class AppBarProfile extends StatelessWidget {
  /// title string
  final String title;

  /// bottom bar widget
  final Widget? bottomBar;

  /// action list
  final List<Widget>? actions;

  /// photo URL
  final String? photoUrl;

  /// on press function
  final void Function()? onPress;
  AppBarProfile(this.title,
      {this.bottomBar, this.actions, this.photoUrl, this.onPress});

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(top: 30.0),
      color: Colors.white,
      height: bottomBar == null ? 110.0 : 160.0,
      child: bottomBar == null
          ? _titleBar(context)
          : Column(
              children: <Widget>[
                Container(height: 80.0, child: _titleBar(context)),
                bottomBar ?? Container()
              ],
            ),
    );
  }

  _titleBar(context) {
    return Row(children: <Widget>[
      GestureDetector(
          onTap: onPress ??
              // () => AppNavigator.navigateToNamed(context, '/setting'),
              () => AppNavigator.showAppDialogEx(
                  context, () => SettingPage(true),
                  size: DialogBoxSizes.large,
                  barrierDismissible: true,
                  title: AppLocale.translate('Settings')),
          child: Container(
              width: 70.0,
              height: 100.0,
              child: Stack(
                children: <Widget>[
                  Image.asset(
                    'assets/images/profile back.png',
                    fit: BoxFit.fill,
                    width: 70.0,
                    height: 100.0,
                  ),
                  Padding(
                      padding: EdgeInsets.only(top: 15.5, left: 17),
                      child: CircleAvatar(
                        minRadius: 24.5,
                        maxRadius: 24.5,
                        backgroundColor: Colors.white,
                        child: CachedNetworkImage(
                          imageUrl: getUrlEx(
                                  photoUrl) ?? // ConfigService.user?.url ??
                              'https://upload.wikimedia.org/wikipedia/commons/7/7c/Profile_avatar_placeholder_large.png',
                          imageBuilder: (context, imageProvider) => PhotoView(
                            imageProvider: imageProvider,
                          ),
                          placeholder: (context, url) =>
                              const Center(child: CircularProgressIndicator()),
                          errorWidget: (context, url, error) =>
                              const Icon(Icons.error),
                        ),
                        // backgroundImage: NetworkImage(getUrlEx(
                        //         photoUrl) ?? // ConfigService.user?.url ??
                        //     'https://upload.wikimedia.org/wikipedia/commons/7/7c/Profile_avatar_placeholder_large.png'),
                      ))
                ],
              ))),

      //SizedBox(width: 70.0),
      Expanded(
          child: TecfyText(title,
              textAlign: TextAlign.center,
              style: TextStyle(
                  color: ThemeService.mainColor,
                  fontSize: 20.0,
                  fontWeight: FontWeight.w600))),
      // IconButton(
      //     onPressed: () {},
      //     icon: Icon(Icons.search,
      //         size: 35.0, color: ThemeService.mainColor)),
      actions != null && actions!.length > 0
          ? actions!.first
          : SizedBox(width: 70.0),
      actions != null && actions!.length > 1 ? actions!.last : Container(),
      SizedBox(width: 20.0)
    ]);
  }
}
